==> skrooge-0.5.4.tar.bz2: skrooge-0.5.4/tests/suite_squish/shared/scripts/skrooge_functions.py <==
import os

def initSimple():
    waitForObject(":Tip of the Day – Skrooge.Close_KPushButton")
    clickButton(":Tip of the Day – Skrooge.Close_KPushButton")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    changeWindowState(":Untitled [modified] - skrooge_SKGMainPanel", "Maximize")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QMoveEvent", ":Untitled [modified] - skrooge_SKGMainPanel", -4, -4, 1506, 17)
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QResizeEvent", ":Untitled [modified] - skrooge_SKGMainPanel", 1680, 991, 1506, 17)

def initAllPlugins():
    waitForObject(":Tip of the Day – Skrooge.Close_KPushButton")
    clickButton(":Tip of the Day – Skrooge.Close_KPushButton")
    waitForObject(":Untitled - skrooge_SKGMainPanel")
    changeWindowState(":Untitled - skrooge_SKGMainPanel", "Maximize")
    waitForObject(":Untitled - skrooge_SKGMainPanel")
    sendEvent("QResizeEvent", ":Untitled - skrooge_SKGMainPanel", 1680, 991, 1506, 17)
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+O>")
    waitForObject(":Name:_KUrlComboBox")
    mouseClick(":Name:_KUrlComboBox", 89, 5, 0, Qt.LeftButton)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", os.getenv('IN')+"all_plugins.skg")
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")
    
def initAllPluginsAndOpenAllPages():
    initAllPlugins()

    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+1>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+2>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+3>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+4>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+5>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+6>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+7>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+8>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+9>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+0>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+1>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    
def bookmarkAndRemoveCurrentPage():
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 181, 151, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    mouseClick(":&Bookmark.kBookmarksList_SKGTreeView", 173, 147, 0, Qt.LeftButton)
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    type(":&Bookmark.kBookmarksList_SKGTreeView", "<Up>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    type(":&Bookmark.kBookmarksList_SKGTreeView", "<Down>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 181, 151, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")   
    
def inportFile(file):    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    type(":Untitled [modified] - skrooge.Import_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    type(":Untitled [modified] - skrooge.Import_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    sendEvent("QKeyEvent", ":Untitled [modified] - skrooge.Import_KMenu", QEvent.KeyPress, 16777220, 13, 0, "\r", False, 1)
    
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", file)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")

==> skrooge-0.7.2.tar.bz2: skrooge-0.7.2/tests/suite_squish/shared/scripts/skrooge_functions.py <==
# -*- coding: utf-8 -*-
import os

def initSimple():
    waitForObject(":Tip of the Day – Skrooge.Close_KPushButton")
    clickButton(":Tip of the Day – Skrooge.Close_KPushButton")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QMoveEvent", ":Untitled [modified] - skrooge_SKGMainPanel", -4, -4, 1506, 17)
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QResizeEvent", ":Untitled [modified] - skrooge_SKGMainPanel", 1680, 991, 1506, 17)
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+W>")
#    waitForObject(":Bookmark has been modified - Skrooge.Do not ask again_QCheckBox")
#    clickButton(":Bookmark has been modified - Skrooge.Do not ask again_QCheckBox")
#    waitForObject(":Bookmark has been modified - Skrooge.No_KPushButton")
#    clickButton(":Bookmark has been modified - Skrooge.No_KPushButton")

def initAllPlugins():
    initSimple();
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+O>")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")
    waitForObject(":Name:_KUrlComboBox")
    mouseClick(":Name:_KUrlComboBox", 89, 5, 0, Qt.LeftButton)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", os.getenv('IN')+"all_plugins.skg")
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")

def initAllPluginsAndOpenAllPages():
    initAllPlugins()

    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+1>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+2>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+3>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+4>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+5>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+6>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+7>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+8>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+9>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+0>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+1>")
    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+2>")


def bookmarkAndRemoveCurrentPage():
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 181, 151, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    mouseClick(":&Bookmark.kBookmarksList_SKGTreeView", 173, 147, 0, Qt.LeftButton)
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    type(":&Bookmark.kBookmarksList_SKGTreeView", "<Up>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    type(":&Bookmark.kBookmarksList_SKGTreeView", "<Down>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    type(":&Bookmark.kBookmarksList_SKGTreeView", "<Down>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 181, 151, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")

def inportFile(file):
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    type(":Untitled [modified] - skrooge.Import_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    type(":Untitled [modified] - skrooge.Import_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Import_KMenu")
    sendEvent("QKeyEvent", ":Untitled [modified] - skrooge.Import_KMenu", QEvent.KeyPress, 16777220, 13, 0, "\r", False, 1)

    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", file)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")
    snooze(3)
    

def undo():
    waitForObject(":Untitled [modified] - skrooge.Undo_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Undo_QToolButton")
    snooze(5)

def redo():
    waitForObject(":Untitled [modified] - skrooge.Redo_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Redo_QToolButton")
    snooze(5)
